
'''
This file is automatically generated by setup.py, So don't edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.10.6',
    'branch_nick': '(detached',
    'revision_id': '3d7ca3ccdd7a8b6abe3ece193a3c59e84e1cc845',
    'revno': 4927
}
